==> qpid-broker-plugins-management-amqp-6.1.2-sources.jar: org/apache/qpid/server/management/amqp/ManagementNodeCreator.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.management.amqp;

import org.apache.qpid.server.plugin.PluggableService;
import org.apache.qpid.server.plugin.SystemNodeCreator;
import org.apache.qpid.server.util.Action;

@PluggableService
public class ManagementNodeCreator implements SystemNodeCreator
{
    @Override
    public void register(final SystemNodeRegistry registry)
    {
        ManagementNode managementNode = new ManagementNode(registry.getVirtualHost(),
                                                           registry.getVirtualHost(), new Action<ManagementNode>()
                {
                    @Override
                    public void performAction(final ManagementNode node)
                    {
                        registry.removeSystemNode(node);
                    }
                });
        registry.registerSystemNode(managementNode);
    }

    @Override
    public String getType()
    {
        return "AMQP-VIRTUALHOST-MANAGEMENT";
    }
}

==> qpid-broker-plugins-management-amqp-7.1.10-sources.jar: org/apache/qpid/server/management/amqp/ManagementNodeCreator.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.management.amqp;

import org.apache.qpid.server.plugin.PluggableService;
import org.apache.qpid.server.plugin.SystemNodeCreator;
import org.apache.qpid.server.util.Action;

@PluggableService
public class ManagementNodeCreator implements SystemNodeCreator
{
    @Override
    public void register(final SystemNodeRegistry registry)
    {
        ManagementNode managementNode = new ManagementNode(registry.getVirtualHost(),
                                                           registry.getVirtualHost());
        registry.registerSystemNode(managementNode);
    }

    @Override
    public String getType()
    {
        return "AMQP-VIRTUALHOST-MANAGEMENT";
    }
}
